@@ -26,12 +26,24 @@ class KubernetesTemplateCli(KubernetesCliBase):
     生成k8s yaml模板，不依赖于k8s配置
     """
 
-    def __init__(self, kind=('deployment',), namespace=None, name=None, image=None, replicas=1):
+    def __init__(self, kind=('deployment',), namespace=None, name=None, image=None, replicas=1,
+                 imagePullSecrets=None, nodeSelector=None, tolerations=None,
+                 rrm='50Mi', rrc='100m', rre=None,
+                 rlm='50Mi', rlc='100m', rle=None):
         self._kind = self._parse_kind(kind)
         self._namespace = self._parse_arg(namespace)
         self._name = self._parse_arg(name)
         self._image = self._parse_arg(image)
         self._replicas = replicas
+        self._imagePullSecrets = self._parse_arg(imagePullSecrets)
+        self._nodeSelector = self._parse_arg(nodeSelector)
+        self._tolerations = self._parse_arg(tolerations)
+        self._rrm = self._parse_arg(rrm)  # resources.requests.memory
+        self._rrc = self._parse_arg(rrc)  # resources.requests.cpu
+        self._rre = self._parse_arg(rre)  # resources.requests.ephemeral-storage
+        self._rlm = self._parse_arg(rlm)  # resources.limits.memory
+        self._rlc = self._parse_arg(rlc)  # resources.limits.cpu
+        self._rle = self._parse_arg(rle)  # resources.limits.ephemeral-storage
 
     def _parse_arg(self, arg):
         return None if isinstance(arg, bool) else arg
